# zs-python - A collection of zaaksysteem utilities

This is a collection of little helpers to list and manipulate the valuesfiles of the zaaksysteem charts
and run common tasks on AWS.


## Installing

To install, use `pip3`:

```
git clone git@gitlab.com:mintlab/devops/utils.git
cd utils/zs-python
pip3 install .
```

## Usage

See the docs directory for the individual utilities
